AMYPAD Core
===========

|Tests|

Basic functionality needed for `AMYPAD <https://github.com/AMYPAD/AMYPAD>`_.


Install
-------

Intended for inclusion in requirements for other packages.
The package name is ``amypad-core``. Options include:

- nii

To install options and their dependencies,
use the package name ``amypad-core[option1,option2]``.


.. |Tests| image:: https://img.shields.io/github/workflow/status/AMYPAD/amypad-core/Test
   :target: https://github.com/AMYPAD/amypad-core/actions
